@@ -32,7 +32,7 @@ def test_a():
     ).run_inline()
 
 
-def test_tests_dir():
+def test_test_dir():
 
     Example(
         {
@@ -73,6 +73,90 @@ def test_a():
     )
 
 
+def test_invalid_test_dir():
+
+    Example(
+        {
+            "pyproject.toml": """\
+[tool.inline-snapshot]
+test-dir=0
+""",
+            "my_tests/test_a.py": """\
+def test_a():
+    pass
+""",
+        }
+    ).run_pytest(
+        stderr=snapshot(
+            "ERROR: test-dir has to be a directory or list of directories\n"
+        ),
+        returncode=snapshot(4),
+    )
+
+
+def test_multiple_test_dirs():
+
+    Example(
+        {
+            "pyproject.toml": """\
+[tool.inline-snapshot]
+test-dir=["my_tests_a","my_tests_b"]
+default-storage="hash"
+""",
+            "my_tests_a/test_a.py": """\
+from inline_snapshot import external
+
+def test_a():
+    assert "a" == external()
+""",
+            "my_tests_b/test_b.py": """\
+from inline_snapshot import external
+
+def test_b():
+    assert "b" == external()
+""",
+        }
+    ).run_inline(
+        ["--inline-snapshot=create,trim"],
+        changed_files=snapshot(
+            {
+                ".inline-snapshot/external/3e23e8160039594a33894f6564e1b1348bbd7a0088d42c4acb73eeaed59c009d.txt": "b",
+                ".inline-snapshot/external/ca978112ca1bbdcafac231b39a23dc4da786eff8147c4e72b9807785afee48bb.txt": "a",
+                "my_tests_a/test_a.py": """\
+from inline_snapshot import external
+
+def test_a():
+    assert "a" == external("hash:ca978112ca1b*.txt")
+""",
+                "my_tests_b/test_b.py": """\
+from inline_snapshot import external
+
+def test_b():
+    assert "b" == external("hash:3e23e8160039*.txt")
+""",
+            }
+        ),
+    ).run_pytest(
+        ["my_tests_b/test_b.py", "--inline-snapshot=trim,create"],
+        changed_files=snapshot({}),
+    ).with_files(
+        {
+            "pyproject.toml": """\
+[tool.inline-snapshot]
+test-dir=["my_tests_b"]
+default-storage="hash"
+"""
+        }
+    ).run_pytest(
+        ["my_tests_b/test_b.py", "--inline-snapshot=trim"],
+        changed_files=snapshot(
+            {
+                ".inline-snapshot/external/ca978112ca1bbdcafac231b39a23dc4da786eff8147c4e72b9807785afee48bb.txt": None
+            }
+        ),
+    )
+
+
 def test_no_test_dir():
     Example(
         {
