@@ -779,18 +779,24 @@ Please fix the way your object is copied or your __eq__ implementation.
 
 def test_unknown_flag():
 
-    Example(
+    e = Example(
         """\
 def test_a():
     assert 1==1
 """
-    ).run_pytest(
+    )
+
+    error = snapshot("ERROR: --inline-snapshot=creaigflen is a unknown flag\n")
+
+    e.run_pytest(
         ["--inline-snapshot=creaigflen"],
         report=snapshot(""),
         returncode=snapshot(4),
-        stderr=snapshot("ERROR: --inline-snapshot=creaigflen is a unknown flag\n"),
+        stderr=error,
     )
 
+    e.run_inline(["--inline-snapshot=creaigflen"], stderr=error)
+
 
 @pytest.mark.parametrize("storage_dir", ["tests/snapshots", None])
 def test_storage_dir_config(project, tmp_path, storage_dir):
@@ -1005,3 +1011,24 @@ def test_a():
         ),
         stdin=b"y\n",
     )
+
+
+def test_pytest_configure_exception():
+
+    Example(
+        {
+            "conftest.py": """
+import pytest
+def pytest_configure(config: pytest.Config) -> None:
+
+    pytest.exit(
+        reason="failed",
+        returncode=pytest.ExitCode.INTERRUPTED,
+    )
+""",
+            "test_a.py": """
+def test_a():
+    pass
+             """,
+        }
+    ).run_pytest(stderr=snapshot("Exit: failed"), returncode=snapshot(2))
